import {
  CreateSightPage,
  DevicesPage,
  EditSightPage,
  LoginPage,
  MainPage,
  SightListPage,
  MapPage,
  MediaListPage,
  MediaPreviewPage,
  MediaEditPage,
  CountryListPage,
  CityListPage,
  RouteListPage,
  UserListPage,
  SnapshotListPage,
  CarrierListPage,
  StationListPage,
  VehicleListPage,
  ArticleListPage,
  CityPreviewPage,
  CountryPreviewPage,
  VehiclePreviewPage,
  CarrierPreviewPage,
  SnapshotCreatePage,
  CountryCreatePage,
  CityCreatePage,
  //  CarrierCreatePage,
  VehicleCreatePage,
} from "@pages";
import { authStore, createSightStore, editSightStore } from "@shared";
import { Layout } from "@widgets";
import { runInAction } from "mobx";
import React, { useEffect } from "react";

import {
  createBrowserRouter,
  RouterProvider,
  Navigate,
  Outlet,
  useLocation,
} from "react-router-dom";

const PublicRoute = ({ children }: { children: React.ReactNode }) => {
  const { isAuthenticated } = authStore;
  if (isAuthenticated) {
    return <Navigate to="/sight" replace />;
  }
  return <>{children}</>;
};

const ProtectedRoute = ({ children }: { children: React.ReactNode }) => {
  const { isAuthenticated } = authStore;
  const location = useLocation();
  if (!isAuthenticated) {
    return <Navigate to="/login" replace />;
  }
  if (location.pathname === "/") {
    return <Navigate to="/sight" replace />;
  }
  return <>{children}</>;
};

// Чтобы очистка сторов происходила при смене локации
const ClearStoresWrapper: React.FC<{ children: React.ReactNode }> = ({
  children,
}) => {
  const location = useLocation();

  useEffect(() => {
    editSightStore.clearSightInfo();
    createSightStore.clearCreateSight();
    runInAction(() => {
      editSightStore.hasLoadedCommon = false;
    });
  }, [location]);

  return <>{children}</>;
};

const router = createBrowserRouter([
  {
    path: "/login",
    element: (
      <PublicRoute>
        <LoginPage />
      </PublicRoute>
    ),
  },
  {
    path: "/",
    element: (
      <ProtectedRoute>
        <Layout>
          <ClearStoresWrapper>
            <Outlet />
          </ClearStoresWrapper>
        </Layout>
      </ProtectedRoute>
    ),
    children: [
      { index: true, element: <MainPage /> },

      // Sight
      { path: "sight", element: <SightListPage /> },
      { path: "sight/create", element: <CreateSightPage /> },
      { path: "sight/:id", element: <EditSightPage /> },

      // Device
      { path: "devices", element: <DevicesPage /> },

      // Map
      { path: "map", element: <MapPage /> },

      // Media
      { path: "media", element: <MediaListPage /> },
      { path: "media/:id", element: <MediaPreviewPage /> },
      { path: "media/:id/edit", element: <MediaEditPage /> },

      // Country
      { path: "country", element: <CountryListPage /> },
      { path: "country/create", element: <CountryCreatePage /> },
      { path: "country/:id", element: <CountryPreviewPage /> },
      // City
      { path: "city", element: <CityListPage /> },
      { path: "city/create", element: <CityCreatePage /> },
      { path: "city/:id", element: <CityPreviewPage /> },
      // Route
      { path: "route", element: <RouteListPage /> },

      // User
      { path: "user", element: <UserListPage /> },

      // Snapshot
      { path: "snapshot", element: <SnapshotListPage /> },
      { path: "snapshot/create", element: <SnapshotCreatePage /> },

      // Carrier
      { path: "carrier", element: <CarrierListPage /> },
      // { path: "carrier/create", element: <CarrierCreatePage /> },
      { path: "carrier/:id", element: <CarrierPreviewPage /> },

      // Station
      { path: "station", element: <StationListPage /> },

      // Vehicle
      { path: "vehicle", element: <VehicleListPage /> },
      { path: "vehicle/create", element: <VehicleCreatePage /> },
      { path: "vehicle/:id", element: <VehiclePreviewPage /> },

      // Article
      { path: "article", element: <ArticleListPage /> },

      // { path: "media/create", element: <CreateMediaPage /> },
    ],
  },
]);

export const Router = () => {
  return <RouterProvider router={router} />;
};
