import { Paper } from "@mui/material";
import { carrierStore, mediaStore } from "@shared";
import { MediaViewer } from "@widgets";
import { observer } from "mobx-react-lite";
import { ArrowLeft } from "lucide-react";
import { useEffect } from "react";
import { useNavigate, useParams } from "react-router-dom";

export const CarrierPreviewPage = observer(() => {
  const { id } = useParams();
  const { getCarrier, carrier } = carrierStore;
  const { oneMedia, getOneMedia } = mediaStore;
  const navigate = useNavigate();

  useEffect(() => {
    (async () => {
      const carrierResponse = await getCarrier(Number(id));
      await getOneMedia(carrierResponse?.logo as string);
    })();
  }, [id]);

  return (
    <Paper className="w-full h-full p-3 flex flex-col gap-10">
      {carrier && (
        <>
          <div className="flex justify-between items-center">
            <button
              className="flex items-center gap-2"
              onClick={() => navigate(-1)}
            >
              <ArrowLeft size={20} />
              Назад
            </button>
            {/* <div className="flex gap-2">
              <Button
                variant="contained"
                color="primary"
                onClick={() => navigate(`/carrier/${id}/edit`)}
                startIcon={<Pencil size={20} />}
              >
                Редактировать
              </Button>
              <Button
                variant="contained"
                color="error"
                onClick={() => navigate(`/carrier/${id}/delete`)}
                startIcon={<Trash2 size={20} />}
              >
                Удалить
              </Button>
            </div> */}
          </div>
          <div className="flex flex-col gap-10 w-full">
            <div className="flex flex-col gap-2">
              <h1 className="text-lg font-bold">Полное имя</h1>
              <p>{carrier?.full_name}</p>
            </div>

            <div className="flex flex-col gap-2">
              <h1 className="text-lg font-bold">Полное имя</h1>
              <p>{carrier?.full_name}</p>
            </div>
            <div className="flex flex-col gap-2">
              <h1 className="text-lg font-bold">Город</h1>
              <p>{carrier?.city}</p>
            </div>
            <div className="flex flex-col gap-2 ">
              <h1 className="text-lg font-bold">Основной цвет</h1>
              <div
                className="w-min"
                style={{
                  backgroundColor: `${carrier?.main_color}90`,
                }}
              >
                {carrier?.main_color}
              </div>
            </div>
            <div className="flex flex-col gap-2">
              <h1 className="text-lg font-bold">Цвет левого виджета</h1>
              <div
                className="w-min"
                style={{
                  backgroundColor: `${carrier?.left_color}90`,
                }}
              >
                {carrier?.left_color}
              </div>
            </div>
            <div className="flex flex-col gap-2">
              <h1 className="text-lg font-bold">Цвет правого виджета</h1>
              <div
                className="w-min"
                style={{
                  backgroundColor: `${carrier?.right_color}90`,
                }}
              >
                {carrier?.right_color}
              </div>
            </div>
            <div className="flex flex-col gap-2">
              <h1 className="text-lg font-bold">Краткое имя</h1>
              <p>{carrier?.short_name}</p>
            </div>
            <div className="flex flex-col gap-2">
              <h1 className="text-lg font-bold">Логотип</h1>

              <MediaViewer
                media={{
                  id: oneMedia?.id as string,
                  media_type: oneMedia?.media_type as number,
                  filename: oneMedia?.filename,
                }}
              />
            </div>
          </div>
        </>
      )}
    </Paper>
  );
});
