import {
  Button,
  Paper,
  TextField,
  Select,
  MenuItem,
  FormControl,
  InputLabel,
} from "@mui/material";

import { observer } from "mobx-react-lite";
import { ArrowLeft, Loader2, Save } from "lucide-react";
import { useState } from "react";
import { useNavigate } from "react-router-dom";
import { toast } from "react-toastify";

export const RouteCreatePage = observer(() => {
  const navigate = useNavigate();
  const [routeNumber, setRouteNumber] = useState("");
  const [direction, setDirection] = useState("");
  const [isLoading, setIsLoading] = useState(false);

  return (
    <Paper className="w-full h-full p-3 flex flex-col gap-10">
      <div className="flex justify-between items-center">
        <button
          className="flex items-center gap-2"
          onClick={() => navigate(-1)}
        >
          <ArrowLeft size={20} />
          Назад
        </button>
      </div>
      <h1 className="text-2xl font-bold">Создание маршрута</h1>
      <div className="flex flex-col gap-10 w-full items-end">
        <TextField
          className="w-full"
          label="Номер маршрута"
          required
          value={routeNumber}
          onChange={(e) => setRouteNumber(e.target.value)}
        />
        <FormControl fullWidth>
          <InputLabel>Направление</InputLabel>
          <Select
            value={direction}
            label="Направление"
            onChange={(e) => setDirection(e.target.value)}
            required
          >
            <MenuItem value="forward">Прямое</MenuItem>
            <MenuItem value="backward">Обратное</MenuItem>
          </Select>
        </FormControl>

        <Button
          variant="contained"
          color="primary"
          className="w-min flex gap-2 items-center"
          startIcon={<Save size={20} />}
          onClick={async () => {
            try {
              setIsLoading(true);
              // await createRoute(routeNumber, direction === "forward");
              setIsLoading(false);
              toast.success("Маршрут успешно создан");
              navigate(-1);
            } catch (error) {
              console.error(error);
              toast.error("Произошла ошибка");
            } finally {
              setIsLoading(false);
            }
          }}
          disabled={isLoading}
        >
          {isLoading ? (
            <Loader2 size={20} className="animate-spin" />
          ) : (
            "Сохранить"
          )}
        </Button>
      </div>
    </Paper>
  );
});
