import { DataGrid, GridColDef, GridRenderCellParams } from "@mui/x-data-grid";
import { languageStore, userStore } from "@shared";
import { useEffect, useState } from "react";
import { observer } from "mobx-react-lite";
import { Eye, Trash2 } from "lucide-react";
import { useNavigate } from "react-router-dom";
import { DeleteModal, LanguageSwitcher } from "@widgets";

export const UserListPage = observer(() => {
  const { users, getUsers, deleteUser } = userStore;
  const navigate = useNavigate();
  const [isDeleteModalOpen, setIsDeleteModalOpen] = useState(false);
  const [rowId, setRowId] = useState<number | null>(null); // Lifted state
  const { language } = languageStore;

  useEffect(() => {
    getUsers();
  }, [language]);

  const columns: GridColDef[] = [
    {
      field: "name",
      headerName: "Имя",
      width: 400,
    },
    {
      field: "email",
      headerName: "Email",
      width: 400,
    },
    {
      field: "is_admin",
      headerName: "Роль",
      flex: 1,

      renderCell: (params: GridRenderCellParams) => {
        return (
          <p
            className={
              params.row.is_admin === true ? "text-green-500" : "text-red-500"
            }
          >
            {params.row.is_admin ? "Администратор" : "Пользователь"}
          </p>
        );
      },
    },

    {
      field: "actions",
      headerName: "Действия",
      flex: 1,
      align: "center",
      headerAlign: "center",

      renderCell: (params: GridRenderCellParams) => {
        return (
          <div className="flex h-full gap-7 justify-center items-center">
            <button
              onClick={() => {
                setIsDeleteModalOpen(true);
                setRowId(params.row.id);
              }}
            >
              <Trash2 size={20} className="text-red-500" />
            </button>
          </div>
        );
      },
    },
  ];

  const rows = users.map((user) => ({
    id: user.id,
    email: user.email,
    is_admin: user.is_admin,
    name: user.name,
  }));

  return (
    <>
      <LanguageSwitcher />

      <div style={{ width: "100%" }}>
        <DataGrid
          rows={rows}
          columns={columns}
          hideFooterPagination
          hideFooter
        />
      </div>

      <DeleteModal
        open={isDeleteModalOpen}
        onDelete={async () => {
          if (rowId) {
            await deleteUser(rowId);
          }
          setIsDeleteModalOpen(false);
          setRowId(null);
        }}
        onCancel={() => {
          setIsDeleteModalOpen(false);
          setRowId(null);
        }}
      />
    </>
  );
});
