import { authInstance, editSightStore, Language, languageStore } from "@shared";
import { computed, makeAutoObservable, runInAction } from "mobx";

export type Article = {
  id: number;
  heading: string;
  body: string;
  service_name: string;
};

type Media = {
  id: string;
  filename: string;
  media_name: string;
  media_type: number;
};

class ArticlesStore {
  constructor() {
    makeAutoObservable(this);
  }

  articles: { [key in Language]: Article[] } = {
    ru: [],
    en: [],
    zh: [],
  };
  articleList: Article[] = [];
  articleData: Article | null = null;
  articleMedia: Media | null = null;
  articleLoading: boolean = false;

  getArticleList = async () => {
    const response = await authInstance.get("/article");

    runInAction(() => {
      this.articleList = response.data;
    });
  };

  getArticles = async (language: Language) => {
    this.articleLoading = true;
    const response = await authInstance.get("/article");

    runInAction(() => {
      this.articles[language] = response.data;
    });
    this.articleLoading = false;
  };

  getArticle = async (id: number) => {
    this.articleLoading = true;
    const response = await authInstance.get(`/article/${id}`);

    runInAction(() => {
      this.articleData = response.data;
    });
    this.articleLoading = false;
  };

  getSightArticles = async (id: number) => {
    const response = await authInstance.get(`/sight/${id}/article`);

    runInAction(() => {
      editSightStore.sight[languageStore.language].right = response.data;
    });
  };

  getArticleMedia = async (id: number) => {
    const response = await authInstance.get(`/article/${id}/media`);

    runInAction(() => {
      this.articleMedia = response.data[0];
    });
  };

  getArticleByArticleId = computed(() => {
    if (editSightStore.sight.common.left_article) {
      const language = languageStore.language;
      const foundArticle = this.articles[language].find(
        (a) => a.id == editSightStore.sight.common.left_article
      );
      editSightStore.sight[language].left.heading = foundArticle?.heading ?? "";
      editSightStore.sight[language].left.body = foundArticle?.body ?? "";
      return foundArticle;
    }
    return null;
  });
}

export const articlesStore = new ArticlesStore();
