import { makeAutoObservable, runInAction } from "mobx";
import { authInstance } from "@shared";

export type Route = {
  carrier: string;
  carrier_id: number;
  center_latitude: number;
  center_longitude: number;
  governor_appeal: number;
  id: number;
  path: number[][];
  rotate: number;
  route_direction: boolean;
  route_number: string;
  route_sys_number: string;
  scale_max: number;
  scale_min: number;
  video_preview: string;
};

class RouteStore {
  routes: Route[] = [];

  constructor() {
    makeAutoObservable(this);
  }

  getRoutes = async () => {
    const response = await authInstance.get("/route");

    runInAction(() => {
      this.routes = response.data;
    });
  };

  deleteRoute = async (id: number) => {
    await authInstance.delete(`/route/${id}`);

    runInAction(() => {
      this.routes = this.routes.filter((route) => route.id !== id);
    });
  };
}

export const routeStore = new RouteStore();