import { authInstance } from "@shared";
import { makeAutoObservable, runInAction } from "mobx";

export type User = {
  id: number;
  email: string;
  is_admin: boolean;
  name: string;
};

class UserStore {
  users: User[] = [];
  user: User | null = null;

  constructor() {
    makeAutoObservable(this);
  }

  getUsers = async () => {
    const response = await authInstance.get("/user");

    runInAction(() => {
      this.users = response.data;
    });
  };

  getUser = async (id: number) => {
    const response = await authInstance.get(`/user/${id}`);

    runInAction(() => {
      this.user = response.data as User;
    });
  };

  deleteUser = async (id: number) => {
    await authInstance.delete(`/users/${id}`);

    runInAction(() => {
      this.users = this.users.filter((user) => user.id !== id);
    });
  };
}

export const userStore = new UserStore();
