import { authInstance } from "@shared";
import { makeAutoObservable } from "mobx";

export type Vehicle = {
  vehicle: {
    id: number;
    tail_number: number;
    type: number;
    carrier_id: number;
    carrier: string;
    uuid?: string;
  };
  device_status?: {
    device_uuid: string;
    online: boolean;
    gps_ok: boolean;
    media_service_ok: boolean;
    last_update: string;
    is_connected: boolean;
  };
};

class VehicleStore {
  vehicles: Vehicle[] = [];
  vehicle: Vehicle | null = null;

  constructor() {
    makeAutoObservable(this);
  }

  getVehicles = async () => {
    const response = await authInstance.get(`/vehicle`);
    this.vehicles = response.data;
  };

  deleteVehicle = async (id: number) => {
    await authInstance.delete(`/vehicle/${id}`);
    this.vehicles = this.vehicles.filter(
      (vehicle) => vehicle.vehicle.id !== id
    );
  };

  getVehicle = async (id: number) => {
    const response = await authInstance.get(`/vehicle/${id}`);
    this.vehicle = response.data;
  };

  createVehicle = async (
    tailNumber: number,
    type: string,
    carrier: string,
    carrierId: number
  ) => {
    await authInstance.post("/vehicle", {
      tail_number: tailNumber,
      type,
      carrier,
      carrier_id: carrierId,
    });
    await this.getVehicles();
  };
}

export const vehicleStore = new VehicleStore();
